@@ -1,4 +1,5 @@
-from django.contrib.auth.views import SuccessURLAllowedHostsMixin
+from typing import Set
+
 from django.http import HttpResponseRedirect
 
 
@@ -8,6 +9,13 @@ except ImportError:  # Django < 3.0
     from django.utils.http import is_safe_url as url_has_allowed_host_and_scheme
 
 
+class SuccessURLAllowedHostsMixin:
+    success_url_allowed_hosts: Set[str] = set()
+
+    def get_success_url_allowed_hosts(self):
+        return {self.request.get_host(), *self.success_url_allowed_hosts}
+
+
 class GetNextPageMixin(SuccessURLAllowedHostsMixin):
     next_url_param_name = "next"
 
